==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/OpenStreetMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { OpenStreetMapImageryDescription } from "./OpenStreetMapImageryDescription";
/**
 * @hidden
 */
var OpenStreetMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OpenStreetMapImageryDescriptionMetadata, _super);
    function OpenStreetMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OpenStreetMapImageryDescriptionMetadata.b = function (a) {
        if (OpenStreetMapImageryDescriptionMetadata.a == null) {
            OpenStreetMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OpenStreetMapImageryDescriptionMetadata.c(OpenStreetMapImageryDescriptionMetadata.a);
        }
        if (a.j(OpenStreetMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.y(OpenStreetMapImageryDescriptionMetadata.a);
    };
    OpenStreetMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("TilePath", "String");
    };
    OpenStreetMapImageryDescriptionMetadata.d = function (a) {
        OpenStreetMapImageryDescriptionMetadata.b(a);
        a.aa("OpenStreetMapImagery", function () { return new OpenStreetMapImageryDescription(); });
        a.z("OpenStreetMapImagery", OpenStreetMapImageryDescriptionMetadata.a);
    };
    OpenStreetMapImageryDescriptionMetadata.$t = markType(OpenStreetMapImageryDescriptionMetadata, 'OpenStreetMapImageryDescriptionMetadata');
    OpenStreetMapImageryDescriptionMetadata.a = null;
    return OpenStreetMapImageryDescriptionMetadata;
}(Base));
export { OpenStreetMapImageryDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/OpenStreetMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { OpenStreetMapImageryDescription } from "./OpenStreetMapImageryDescription";
/**
 * @hidden
 */
var OpenStreetMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OpenStreetMapImageryDescriptionMetadata, _super);
    function OpenStreetMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OpenStreetMapImageryDescriptionMetadata.b = function (a) {
        if (OpenStreetMapImageryDescriptionMetadata.a == null) {
            OpenStreetMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OpenStreetMapImageryDescriptionMetadata.c(OpenStreetMapImageryDescriptionMetadata.a);
        }
        if (a.k(OpenStreetMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.aa(OpenStreetMapImageryDescriptionMetadata.a);
    };
    OpenStreetMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("TilePath", "String");
    };
    OpenStreetMapImageryDescriptionMetadata.d = function (a) {
        OpenStreetMapImageryDescriptionMetadata.b(a);
        a.ac("OpenStreetMapImagery", function () { return new OpenStreetMapImageryDescription(); });
        a.ab("OpenStreetMapImagery", OpenStreetMapImageryDescriptionMetadata.a);
    };
    OpenStreetMapImageryDescriptionMetadata.$t = markType(OpenStreetMapImageryDescriptionMetadata, 'OpenStreetMapImageryDescriptionMetadata');
    OpenStreetMapImageryDescriptionMetadata.a = null;
    return OpenStreetMapImageryDescriptionMetadata;
}(Base));
export { OpenStreetMapImageryDescriptionMetadata };
